@@ -1,18 +1,3 @@
-SUBSISTEMAS = ["SE", "S", "NE", "N", "FC"]
-REES = [
-    "SUDESTE",
-    "SUL",
-    "NORDESTE",
-    "NORTE",
-    "ITAIPU",
-    "MADEIRA",
-    "TPIRES",
-    "BMONTE",
-    "MAN-AP",
-    "PARANA",
-    "IGUACU",
-    "PRNPANEMA",
-]
 MAX_PATAMARES = 5
 MAX_SEMANAS_PRE = 10
 MAX_ESTAGIOS = 10
@@ -49,3 +34,17 @@ MESES_DF = [
     "Novembro",
     "Dezembro",
 ]
+MESES_ABREV = [
+    "JAN",
+    "FEV",
+    "MAR",
+    "ABR",
+    "MAI",
+    "JUN",
+    "JUL",
+    "AGO",
+    "SET",
+    "OUT",
+    "NOV",
+    "DEZ",
+]
